@@ -30,7 +30,7 @@ install_pgcli_venv(){
 odoo_conf(){
     export ODOO_CONF=/home/odoo/.openerp_serverrc
     /entry_point.py run true
-    sed -i '/db_host\|db_password\|db_user/d' $ODOO_CONF
+    sed -i '/db_host\|db_password\|db_user\|workers/d' $ODOO_CONF
     su odoo -c "mkdir -p $ODOORC_DATA_DIR"
 }
 
